[PATCH][next] drm/msm: a6xx: fix spelling mistake: "initalization" -> "initialization"

Colin King colin.king at canonical.com
Wed Aug 8 17:18:33 UTC 2018


From: Colin Ian King <colin.king at canonical.com>

Trivial fix to spelling mistake in dev_err message and comment

Signed-off-by: Colin Ian King <colin.king at canonical.com>
---
 drivers/gpu/drm/msm/adreno/a6xx_gmu.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/gpu/drm/msm/adreno/a6xx_gmu.c b/drivers/gpu/drm/msm/adreno/a6xx_gmu.c
index fbb501986720..bbb8126ec5c5 100644
--- a/drivers/gpu/drm/msm/adreno/a6xx_gmu.c
+++ b/drivers/gpu/drm/msm/adreno/a6xx_gmu.c
@@ -125,7 +125,7 @@ static int a6xx_gmu_start(struct a6xx_gmu *gmu)
 		val == 0xbabeface, 100, 10000);
 
 	if (ret)
-		dev_err(gmu->dev, "GMU firmware initalization timed out\n");
+		dev_err(gmu->dev, "GMU firmware initialization timed out\n");
 
 	return ret;
 }
@@ -1034,7 +1034,7 @@ static int a6xx_gmu_pwrlevels_probe(struct a6xx_gmu *gmu)
 
 	/*
 	 * The GMU handles its own frequency switching so build a list of
 	 * available frequencies to send during initalization
 	 */
 	ret = dev_pm_opp_of_add_table(gmu->dev);
 	if (ret) {
@@ -1034,7 +1034,7 @@ static int a6xx_gmu_pwrlevels_probe(struct a6xx_gmu *gmu)
 	/*
 	 * The GMU handles its own frequency switching so build a list of
-	 * available frequencies to send during initalization
+	 * available frequencies to send during initialization
 	 */
 	ret = dev_pm_opp_of_add_table(gmu->dev);
-- 
2.17.1



More information about the dri-devel mailing list